from setuptools import setup, find_packages

setup(
    name='yvesCMD',
    version='0.0.1',
    packages=["YveCMD"],
    install_requires=[],  
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
